==> zio-aws-apigateway_2.12-6.20.58.2-sources.jar: zio/aws/apigateway/model/UpdateMethodResponseResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.apigateway.model.primitives.{NullableBoolean, StatusCode}
import scala.jdk.CollectionConverters._
final case class UpdateMethodResponseResponse(
    statusCode: Optional[StatusCode] = Optional.Absent,
    responseParameters: Optional[Map[String, NullableBoolean]] =
      Optional.Absent,
    responseModels: Optional[Map[String, String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse = {
    import UpdateMethodResponseResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse
      .builder()
      .optionallyWith(
        statusCode.map(value => StatusCode.unwrap(value): java.lang.String)
      )(_.statusCode)
      .optionallyWith(
        responseParameters.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.Boolean)
            })
            .asJava
        )
      )(_.responseParameters)
      .optionallyWith(
        responseModels.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.responseModels)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.UpdateMethodResponseResponse.ReadOnly =
    zio.aws.apigateway.model.UpdateMethodResponseResponse.wrap(buildAwsValue())
}
object UpdateMethodResponseResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.UpdateMethodResponseResponse =
      zio.aws.apigateway.model.UpdateMethodResponseResponse(
        statusCode.map(value => value),
        responseParameters.map(value => value),
        responseModels.map(value => value)
      )
    def statusCode: Optional[StatusCode]
    def responseParameters: Optional[Map[String, NullableBoolean]]
    def responseModels: Optional[Map[String, String]]
    def getStatusCode: ZIO[Any, AwsError, StatusCode] =
      AwsError.unwrapOptionField("statusCode", statusCode)
    def getResponseParameters
        : ZIO[Any, AwsError, Map[String, NullableBoolean]] =
      AwsError.unwrapOptionField("responseParameters", responseParameters)
    def getResponseModels: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("responseModels", responseModels)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse
  ) extends zio.aws.apigateway.model.UpdateMethodResponseResponse.ReadOnly {
    override val statusCode: Optional[StatusCode] = zio.aws.core.internal
      .optionalFromNullable(impl.statusCode())
      .map(value => zio.aws.apigateway.model.primitives.StatusCode(value))
    override val responseParameters: Optional[Map[String, NullableBoolean]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.responseParameters())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: String) -> (value: NullableBoolean)
            })
            .toMap
        )
    override val responseModels: Optional[Map[String, String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.responseModels())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: String) -> (value: String)
            })
            .toMap
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse
  ): zio.aws.apigateway.model.UpdateMethodResponseResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigateway_2.13-5.17.104.2-sources.jar: zio/aws/apigateway/model/UpdateMethodResponseResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.apigateway.model.primitives.{NullableBoolean, StatusCode}
import scala.jdk.CollectionConverters._
final case class UpdateMethodResponseResponse(
    statusCode: Option[StatusCode] = None,
    responseParameters: Option[Map[String, NullableBoolean]] = None,
    responseModels: Option[Map[String, String]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse = {
    import UpdateMethodResponseResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse
      .builder()
      .optionallyWith(
        statusCode.map(value => StatusCode.unwrap(value): java.lang.String)
      )(_.statusCode)
      .optionallyWith(
        responseParameters.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (NullableBoolean
                .unwrap(value): java.lang.Boolean)
            })
            .asJava
        )
      )(_.responseParameters)
      .optionallyWith(
        responseModels.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.responseModels)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.UpdateMethodResponseResponse.ReadOnly =
    zio.aws.apigateway.model.UpdateMethodResponseResponse.wrap(buildAwsValue())
}
object UpdateMethodResponseResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.UpdateMethodResponseResponse =
      zio.aws.apigateway.model.UpdateMethodResponseResponse(
        statusCode.map(value => value),
        responseParameters.map(value => value),
        responseModels.map(value => value)
      )
    def statusCode: Option[StatusCode]
    def responseParameters: Option[Map[String, NullableBoolean]]
    def responseModels: Option[Map[String, String]]
    def getStatusCode: ZIO[Any, AwsError, StatusCode] =
      AwsError.unwrapOptionField("statusCode", statusCode)
    def getResponseParameters
        : ZIO[Any, AwsError, Map[String, NullableBoolean]] =
      AwsError.unwrapOptionField("responseParameters", responseParameters)
    def getResponseModels: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("responseModels", responseModels)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse
  ) extends zio.aws.apigateway.model.UpdateMethodResponseResponse.ReadOnly {
    override val statusCode: Option[StatusCode] = scala
      .Option(impl.statusCode())
      .map(value => zio.aws.apigateway.model.primitives.StatusCode(value))
    override val responseParameters: Option[Map[String, NullableBoolean]] =
      scala
        .Option(impl.responseParameters())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: String) -> zio.aws.apigateway.model.primitives
                .NullableBoolean(value)
            })
            .toMap
        )
    override val responseModels: Option[Map[String, String]] = scala
      .Option(impl.responseModels())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.UpdateMethodResponseResponse
  ): zio.aws.apigateway.model.UpdateMethodResponseResponse.ReadOnly =
    new Wrapper(impl)
}
